@@ -5,8 +5,10 @@ import re
 
 from openxlab.model.clients.openapi_client import OpenapiClient
 from openxlab.model.common.constants import endpoint, token
+from openxlab.model.common.bury import bury_data
 
 
+@bury_data("remove_file")
 def remove(model_repo) -> None:
     """
     remove repository
@@ -16,7 +18,7 @@ def remove(model_repo) -> None:
         username, repository = _split_repo(model_repo)
         client = OpenapiClient(endpoint, token)
         client.remove_repository(repository)
-        print(f"repository:{repository} visibility update to private successfully.")
+        print(f"repository:{repository} removed successfully.")
     except ValueError as e:
         print(f"Error: {e}")
         return
@@ -27,9 +29,9 @@ def _split_repo(model_repo) -> (str, str):
     Split a full repository name into two separate strings: the username and the repository name.
     """
     # username/repository format check
-    pattern = r'^[a-zA-Z0-9]+\/[a-zA-Z0-9\-_]+$'
+    pattern = r'.+/.+'
     if not re.match(pattern, model_repo):
-        raise ValueError("The input string must be in the format 'didi12/test-d-1'")
+        raise ValueError("The input string must be in the format 'username/model_repo'")
 
     values = model_repo.split('/')
     return values[0], values[1]
