@@ -1,5 +1,12 @@
-from argparse import ArgumentParser, Namespace
-from typing import Any, Dict, List, Optional, Tuple, Type, Union
+from argparse import ArgumentParser
+from argparse import Namespace
+from typing import Any
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import Type
+from typing import Union
 
 
 class BaseCommand:
